@@ -8,7 +8,8 @@ module Vagrant
     # Builtin contains middleware classes that are shipped with Vagrant-core
     # and are thus available to all plugins as a "standard library" of sorts.
     module Builtin
-      autoload :BoxAdd,  "vagrant/action/builtin/box_add"
+      autoload :BoxAdd,    "vagrant/action/builtin/box_add"
+      autoload :BoxRemove, "vagrant/action/builtin/box_remove"
       autoload :Call,    "vagrant/action/builtin/call"
       autoload :Confirm, "vagrant/action/builtin/confirm"
       autoload :ConfigValidate, "vagrant/action/builtin/config_validate"
@@ -18,11 +19,14 @@ module Vagrant
       autoload :HandleBoxUrl, "vagrant/action/builtin/handle_box_url"
       autoload :HandleForwardedPortCollisions, "vagrant/action/builtin/handle_forwarded_port_collisions"
       autoload :Lock, "vagrant/action/builtin/lock"
-      autoload :NFS, "vagrant/action/builtin/nfs"
       autoload :Provision, "vagrant/action/builtin/provision"
+      autoload :ProvisionerCleanup, "vagrant/action/builtin/provisioner_cleanup"
       autoload :SetHostname, "vagrant/action/builtin/set_hostname"
       autoload :SSHExec, "vagrant/action/builtin/ssh_exec"
       autoload :SSHRun,  "vagrant/action/builtin/ssh_run"
+      autoload :SyncedFolders, "vagrant/action/builtin/synced_folders"
+      autoload :SyncedFolderCleanup, "vagrant/action/builtin/synced_folder_cleanup"
+      autoload :WaitForCommunicator, "vagrant/action/builtin/wait_for_communicator"
     end
 
     module General
@@ -39,5 +43,14 @@ module Vagrant
         b.use Builtin::BoxAdd
       end
     end
+
+    # This is the action that will remove a box given a name (and optionally
+    # a provider). This middleware sequence is built-in to Vagrant. Plugins
+    # can hook into this like any other middleware sequence.
+    def self.action_box_remove
+      Builder.new.tap do |b|
+        b.use Builtin::BoxRemove
+      end
+    end
   end
 end
