@@ -70,31 +70,35 @@ module Vagrant
     #   the box represents will be added.
     # @param [Boolean] force If true, any existing box with the same name
     #   and provider will be replaced.
-    def add(path, name, provider=nil, force=false)
+    def add(path, name, formats=nil, force=false)
+      formats = [formats] if formats && !formats.is_a?(Array)
+      provider = nil
+
       with_collection_lock do
         # A helper to check if a box exists. We store this in a variable
         # since we call it multiple times.
-        check_box_exists = lambda do |box_provider|
-          box = find(name, box_provider)
+        check_box_exists = lambda do |box_formats|
+          box = find(name, box_formats)
           next if !box
 
           if !force
-            @logger.error("Box already exists, can't add: #{name} #{box_provider}")
-            raise Errors::BoxAlreadyExists, :name => name, :provider => box_provider
+            @logger.error("Box already exists, can't add: #{name} #{box_formats.join(", ")}")
+            raise Errors::BoxAlreadyExists, :name => name, :formats => box_formats.join(", ")
           end
 
           # We're forcing, so just delete the old box
-          @logger.info("Box already exists, but forcing so removing: #{name} #{box_provider}")
+          @logger.info(
+            "Box already exists, but forcing so removing: #{name} #{box_formats.join(", ")}")
           box.destroy!
         end
 
-        log_provider = provider ? provider : "any provider"
+        log_provider = formats ? formats.join(", ") : "any provider"
         @logger.debug("Adding box: #{name} (#{log_provider}) from #{path}")
 
         # Verify the box doesn't exist early if we're given a provider. This
         # can potentially speed things up considerably since we don't need
         # to unpack any files.
-        check_box_exists.call(provider) if provider
+        check_box_exists.call(formats) if formats
 
         # Verify that a V1 box doesn't exist. If it does, then we signal
         # to the user that we need an upgrade.
@@ -121,26 +125,35 @@ module Vagrant
           with_temp_dir(temp_dir) do |final_temp_dir|
             # Get an instance of the box we just added before it is finalized
             # in the system so we can inspect and use its metadata.
-            box = Box.new(name, provider, final_temp_dir)
+            box = Box.new(name, nil, final_temp_dir)
 
             # Get the provider, since we'll need that to at the least add it
             # to the system or check that it matches what is given to us.
             box_provider = box.metadata["provider"]
 
-            if provider
-              # Verify that the given provider matches what the box has.
-              if box_provider.to_sym != provider
-                @logger.error("Added box provider doesnt match expected: #{box_provider}")
-                raise Errors::BoxProviderDoesntMatch, :expected => provider, :actual => box_provider
+            if formats
+              found = false
+              formats.each do |format|
+                # Verify that the given provider matches what the box has.
+                if box_provider.to_sym == format.to_sym
+                  found = true
+                  break
+                end
+              end
+
+              if !found
+                @logger.error("Added box provider doesnt match expected: #{log_provider}")
+                raise Errors::BoxProviderDoesntMatch,
+                  :expected => log_provider, :actual => box_provider
               end
             else
-              # We weren't given a provider, so store this one.
-              provider = box_provider.to_sym
-
               # Verify the box doesn't already exist
-              check_box_exists.call(provider)
+              check_box_exists.call([box_provider])
             end
 
+            # We weren't given a provider, so store this one.
+            provider = box_provider.to_sym
+
             # Create the directory for this box, not including the provider
             box_dir = @directory.join(name)
             box_dir.mkpath
@@ -220,39 +233,43 @@ module Vagrant
     # Find a box in the collection with the given name and provider.
     #
     # @param [String] name Name of the box (logical name).
-    # @Param [String] provider Provider that the box implements.
+    # @param [Array] providers Providers that the box implements.
     # @return [Box] The box found, or `nil` if not found.
-    def find(name, provider)
-      with_collection_lock do
-        # First look directly for the box we're asking for.
-        box_directory = @directory.join(name, provider.to_s, "metadata.json")
-        @logger.info("Searching for box: #{name} (#{provider}) in #{box_directory}")
-        if box_directory.file?
-          @logger.info("Box found: #{name} (#{provider})")
-          return Box.new(name, provider, box_directory.dirname)
-        end
+    def find(name, providers)
+      providers = [providers].flatten
 
-        # If we're looking for a VirtualBox box, then we check if there is
-        # a V1 box.
-        if provider == :virtualbox
-          # Check if a V1 version of this box exists, and if so, raise an
-          # exception notifying the caller that the box exists but needs
-          # to be upgraded. We don't do the upgrade here because it can be
-          # a fairly intensive activity and don't want to immediately degrade
-          # user performance on a find.
-          #
-          # To determine if it is a V1 box we just do a simple heuristic
-          # based approach.
-          @logger.info("Searching for V1 box: #{name}")
-          if v1_box?(@directory.join(name))
-            @logger.warn("V1 box found: #{name}")
-            raise Errors::BoxUpgradeRequired, :name => name
+      with_collection_lock do
+        providers.each do |provider|
+          # First look directly for the box we're asking for.
+          box_directory = @directory.join(name, provider.to_s, "metadata.json")
+          @logger.info("Searching for box: #{name} (#{provider}) in #{box_directory}")
+          if box_directory.file?
+            @logger.info("Box found: #{name} (#{provider})")
+            return Box.new(name, provider, box_directory.dirname)
+          end
+
+          # If we're looking for a VirtualBox box, then we check if there is
+          # a V1 box.
+          if provider.to_sym == :virtualbox
+            # Check if a V1 version of this box exists, and if so, raise an
+            # exception notifying the caller that the box exists but needs
+            # to be upgraded. We don't do the upgrade here because it can be
+            # a fairly intensive activity and don't want to immediately degrade
+            # user performance on a find.
+            #
+            # To determine if it is a V1 box we just do a simple heuristic
+            # based approach.
+            @logger.info("Searching for V1 box: #{name}")
+            if v1_box?(@directory.join(name))
+              @logger.warn("V1 box found: #{name}")
+              raise Errors::BoxUpgradeRequired, :name => name
+            end
           end
         end
       end
 
       # Didn't find it, return nil
-      @logger.info("Box not found: #{name} (#{provider})")
+      @logger.info("Box not found: #{name} (#{providers.join(", ")})")
       nil
     end
 
@@ -261,6 +278,7 @@ module Vagrant
     # If the given box is found but is not a V1 box then `true` is returned
     # because this just works fine.
     #
+    # @param [String] name Name of the box (logical name).
     # @return [Boolean] `true` otherwise an exception is raised.
     def upgrade(name)
       with_collection_lock do
@@ -268,7 +286,7 @@ module Vagrant
         box_dir = @directory.join(name)
 
         # If the box doesn't exist at all, raise an exception
-        raise Errors::BoxNotFound, :name => name if !box_dir.directory?
+        raise Errors::BoxNotFound, :name => name, :provider => "virtualbox" if !box_dir.directory?
 
         if v1_box?(box_dir)
           @logger.debug("V1 box #{name} found. Upgrading!")
