@@ -14,15 +14,7 @@ module Vagrant
     end
 
     def execute
-      if @main_args.include?("-v") || @main_args.include?("--version")
-        # Version short-circuits the whole thing. Just print
-        # the version and exit.
-        @env.ui.info(I18n.t("vagrant.commands.version.output",
-                            :version => Vagrant::VERSION),
-                     :prefix => false)
-
-        return 0
-      elsif @main_args.include?("-h") || @main_args.include?("--help")
+      if @main_args.include?("-h") || @main_args.include?("--help")
         # Help is next in short-circuiting everything. Print
         # the help and exit.
         help
@@ -63,13 +55,17 @@ module Vagrant
 
         # Add the available subcommands as separators in order to print them
         # out as well.
-        keys = []
-        Vagrant.plugin("2").manager.commands.each do |key, _|
-          keys << key
+        commands = {}
+        longest = 0
+        Vagrant.plugin("2").manager.commands.each do |key, klass|
+          key = key.to_s
+          commands[key] = klass.synopsis
+          longest = key.length if key.length > longest
         end
 
-        keys.sort.each do |key|
-          o.separator "     #{key}"
+        commands.keys.sort.each do |key|
+          o.separator "     #{key.ljust(longest+2)} #{commands[key]}"
+          @env.ui.machine("cli-command", key.dup)
         end
 
         o.separator ""
