@@ -62,19 +62,21 @@ module Vagrant
     # to the `Dir.pwd` (which is the cwd of the executing process).
     def initialize(opts=nil)
       opts = {
-        :cwd => nil,
-        :home_path => nil,
-        :local_data_path => nil,
-        :lock_path => nil,
-        :ui_class => nil,
-        :vagrantfile_name => nil
+        :cwd              => nil,
+        :home_path        => nil,
+        :local_data_path  => nil,
+        :lock_path        => nil,
+        :ui_class         => nil,
+        :vagrantfile_name => nil,
       }.merge(opts || {})
 
       # Set the default working directory to look for the vagrantfile
       opts[:cwd] ||= ENV["VAGRANT_CWD"] if ENV.has_key?("VAGRANT_CWD")
       opts[:cwd] ||= Dir.pwd
       opts[:cwd] = Pathname.new(opts[:cwd])
-      raise Errors::EnvironmentNonExistentCWD if !opts[:cwd].directory?
+      if !opts[:cwd].directory?
+        raise Errors::EnvironmentNonExistentCWD, cwd: opts[:cwd].to_s
+      end
 
       # Set the default ui class
       opts[:ui_class] ||= UI::Silent
@@ -83,9 +85,8 @@ module Vagrant
       # those continue to work as well, but anything custom will take precedence.
       opts[:vagrantfile_name] ||= ENV["VAGRANT_VAGRANTFILE"] if \
         ENV.has_key?("VAGRANT_VAGRANTFILE")
-      opts[:vagrantfile_name] ||= ["Vagrantfile", "vagrantfile"]
       opts[:vagrantfile_name] = [opts[:vagrantfile_name]] if \
-        !opts[:vagrantfile_name].is_a?(Array)
+        opts[:vagrantfile_name] && !opts[:vagrantfile_name].is_a?(Array)
 
       # Set instance variables for all the configuration parameters.
       @cwd              = opts[:cwd]
@@ -115,11 +116,10 @@ module Vagrant
       # Setup the local data directory. If a configuration path is given,
       # then it is expanded relative to the working directory. Otherwise,
       # we use the default which is expanded relative to the root path.
-      @local_data_path = nil
+      opts[:local_data_path] ||= ENV["VAGRANT_DOTFILE_PATH"]
+      opts[:local_data_path] ||= root_path.join(DEFAULT_LOCAL_DATA) if !root_path.nil?
       if opts[:local_data_path]
         @local_data_path = Pathname.new(File.expand_path(opts[:local_data_path], @cwd))
-      elsif !root_path.nil?
-        @local_data_path = root_path.join(DEFAULT_LOCAL_DATA)
       end
 
       setup_local_data_path
@@ -131,6 +131,10 @@ module Vagrant
       # Load the plugins
       load_plugins
 
+      # Call the hooks that does not require configurations to be loaded
+      # by using a "clean" action runner
+      hook(:environment_plugins_loaded, runner: Action::Runner.new(env: self))
+
       # Call the environment load hooks
       hook(:environment_load)
     end
@@ -244,7 +248,7 @@ module Vagrant
       home_vagrantfile = nil
       root_vagrantfile = nil
       home_vagrantfile = find_vagrantfile(home_path) if home_path
-      root_vagrantfile = find_vagrantfile(root_path) if root_path
+      root_vagrantfile = find_vagrantfile(root_path, @vagrantfile_name) if root_path
 
       # Create the configuration loader and set the sources that are global.
       # We use this to load the configuration, and the list of machines we are
@@ -268,13 +272,15 @@ module Vagrant
     # against the given name will be run in the context of this environment.
     #
     # @param [Symbol] name Name of the hook.
-    def hook(name)
+    # @param [Action::Runner] action_runner A custom action runner for running hooks.
+    def hook(name, opts=nil)
       @logger.info("Running hook: #{name}")
-      callable = Action::Builder.new
-      action_runner.run(
-        callable,
-        :action_name => name,
-        :env => self)
+      opts ||= {}
+      opts[:callable] ||= Action::Builder.new
+      opts[:runner] ||= action_runner
+      opts[:action_name] = name
+      opts[:env] = self
+      opts.delete(:runner).run(opts.delete(:callable), opts)
     end
 
     # This returns a machine with the proper provider for this environment.
@@ -338,7 +344,17 @@ module Vagrant
       box_changed  = false
 
       load_box_and_overrides = lambda do
-        box = find_box(config.vm.box, box_formats) if config.vm.box
+        box = nil
+        if config.vm.box
+          begin
+            box = boxes.find(config.vm.box, box_formats)
+          rescue Errors::BoxUpgradeRequired
+            # Upgrade the box if we must
+            @logger.info("Upgrading box during config load: #{config.vm.box}")
+            boxes.upgrade(config.vm.box)
+            retry
+          end
+        end
 
         # If a box was found, then we attempt to load the Vagrantfile for
         # that box. We don't require a box since we allow providers to download
@@ -405,8 +421,9 @@ module Vagrant
           "config/messages",
           :warnings => config_warnings,
           :errors => config_errors).chomp
-          @ui.send(level, I18n.t("vagrant.general.config_upgrade_messages",
-                                 :output => output))
+        @ui.send(level, I18n.t("vagrant.general.config_upgrade_messages",
+                               name: name,
+                               :output => output))
 
           # If we had errors, then we bail
           raise Errors::ConfigUpgradeErrors if !config_errors.empty?
@@ -500,6 +517,7 @@ module Vagrant
           :action_runner  => action_runner,
           :box_collection => boxes,
           :global_config  => config_global,
+          :hook           => method(:hook),
           :host           => host,
           :gems_path      => gems_path,
           :home_path      => home_path,
@@ -521,11 +539,8 @@ module Vagrant
       root_finder = lambda do |path|
         # Note: To remain compatible with Ruby 1.8, we have to use
         # a `find` here instead of an `each`.
-        found = vagrantfile_name.find do |rootfile|
-          File.exist?(File.join(path.to_s, rootfile))
-        end
-
-        return path if found
+        vf = find_vagrantfile(path, @vagrantfile_name)
+        return path if vf
         return nil if path.root? || !File.exist?(path)
         root_finder.call(path.parent)
       end
@@ -693,47 +708,15 @@ module Vagrant
       Pathname.new(path)
     end
 
-    # This finds a box for the given name and formats, or returns nil
-    # if the box isn't found.
-    #
-    # @param [String] name Name of the box
-    # @param [Array<Symbol>] formats The formats to search for the box.
-    # @return [Box]
-    def find_box(name, formats)
-      # Determine the box formats we support
-      formats = [formats] if !formats.is_a?(Array)
-
-      @logger.info("Provider-supported box formats: #{formats.inspect}")
-      formats.each do |format|
-        box = nil
-
-        begin
-          box = boxes.find(name, format.to_s)
-        rescue Errors::BoxUpgradeRequired
-          # Upgrade the box if we must
-          @logger.info("Upgrading box during config load: #{name}")
-          boxes.upgrade(name)
-          retry
-        end
-
-        # If a box was found, we exit
-        if box
-          @logger.info("Box found with format: #{format}")
-          return box
-        end
-      end
-
-      nil
-    end
-
     # Finds the Vagrantfile in the given directory.
     #
     # @param [Pathname] path Path to search in.
     # @return [Pathname]
-    def find_vagrantfile(search_path)
-      @vagrantfile_name.each do |vagrantfile|
+    def find_vagrantfile(search_path, filenames=nil)
+      filenames ||= ["Vagrantfile", "vagrantfile"]
+      filenames.each do |vagrantfile|
         current_path = search_path.join(vagrantfile)
-        return current_path if current_path.exist?
+        return current_path if current_path.file?
       end
 
       nil
@@ -757,21 +740,34 @@ module Vagrant
         end
       end
 
+      # This keeps track of the old plugins that need to be reinstalled
+      # because they were installed with an old version of Ruby.
+      reinstall = []
+
       # Load the plugins
       plugins_json_file = @home_path.join("plugins.json")
       @logger.debug("Loading plugins from: #{plugins_json_file}")
-      if plugins_json_file.file?
-        data = JSON.parse(plugins_json_file.read)
-        data["installed"].each do |plugin|
-          @logger.info("Loading plugin from JSON: #{plugin}")
-          begin
-            Vagrant.require_plugin(plugin)
-          rescue Errors::PluginLoadError => e
-            @ui.error(e.message + "\n")
-          rescue Errors::PluginLoadFailed => e
-            @ui.error(e.message + "\n")
-          end
+      state = VagrantPlugins::CommandPlugin::StateFile.new(plugins_json_file)
+      state.installed_plugins.each do |name, extra|
+        # If the Ruby version changed, then they need to reinstall the plugin
+        if extra["ruby_version"] != RUBY_VERSION
+          reinstall << name
+          next
         end
+
+        @logger.info("Loading plugin from JSON: #{name}")
+        begin
+          Vagrant.require_plugin(name)
+        rescue Errors::PluginLoadError => e
+          @ui.error(e.message + "\n")
+        rescue Errors::PluginLoadFailed => e
+          @ui.error(e.message + "\n")
+        end
+      end
+
+      if !reinstall.empty?
+        @ui.warn(I18n.t("vagrant.plugin_needs_reinstall",
+          names: reinstall.join(", ")))
       end
     end
 
