@@ -48,6 +48,10 @@ module Vagrant
         error_namespace(namespace) if namespace
       end
 
+      def self.error_message(message)
+        define_method(:error_message) { message }
+      end
+
       def self.error_namespace(namespace)
         define_method(:error_namespace) { namespace }
       end
@@ -55,11 +59,20 @@ module Vagrant
       def initialize(message=nil, *args)
         message = { :_key => message } if message && !message.is_a?(Hash)
         message = { :_key => error_key, :_namespace => error_namespace }.merge(message || {})
-        message = translate_error(message)
+
+        if message[:_key]
+          message = translate_error(message)
+        else
+          message = error_message
+        end
 
         super
       end
 
+      # The error message for this error. This is used if no error_key
+      # is specified for a translatable error message.
+      def error_message; "No error message"; end
+
       # The default error namespace which is used for the error key.
       # This can be overridden here or by calling the "error_namespace"
       # class method.
@@ -87,6 +100,10 @@ module Vagrant
       error_key(:active_machine_with_different_provider)
     end
 
+    class AnsibleFailed < VagrantError
+      error_key(:ansible_failed)
+    end
+
     class AnsiblePlaybookAppNotFound < VagrantError
       error_key(:ansible_playbook_app_not_found)
     end
@@ -103,10 +120,22 @@ module Vagrant
       error_key(:already_exists, "vagrant.actions.box.unpackage")
     end
 
+    class BoxChecksumInvalidType < VagrantError
+      error_key(:box_checksum_invalid_type)
+    end
+
+    class BoxChecksumMismatch < VagrantError
+      error_key(:box_checksum_mismatch)
+    end
+
     class BoxConfigChangingBox < VagrantError
       error_key(:box_config_changing_box)
     end
 
+    class BoxMetadataCorrupted < VagrantError
+      error_key(:box_metadata_corrupted)
+    end
+
     class BoxMetadataFileNotFound < VagrantError
       error_key(:box_metadata_file_not_found)
     end
@@ -163,6 +192,14 @@ module Vagrant
       error_key(:cli_invalid_options)
     end
 
+    class CommandUnavailable < VagrantError
+      error_key(:command_unavailable)
+    end
+
+    class CommandUnavailableWindows < CommandUnavailable
+      error_key(:command_unavailable_windows)
+    end
+
     class ConfigInvalid < VagrantError
       error_key(:config_invalid)
     end
@@ -175,6 +212,10 @@ module Vagrant
       error_key(:copy_private_key_failed)
     end
 
+    class DarwinNFSMountFailed < VagrantError
+      error_key(:darwin_nfs_mount_failed)
+    end
+
     class DestroyRequiresForce < VagrantError
       error_key(:destroy_requires_force)
     end
@@ -259,6 +300,10 @@ module Vagrant
       error_key(:guest_capability_not_found)
     end
 
+    class GuestExplicitNotDetected < VagrantError
+      error_key(:guest_explicit_not_detected)
+    end
+
     class GuestNotDetected < VagrantError
       error_key(:guest_not_detected)
     end
@@ -319,6 +364,14 @@ module Vagrant
       error_key(:not_found, "vagrant.actions.vm.host_only_network")
     end
 
+    class NFSBadExports < VagrantError
+      error_key(:nfs_bad_exports)
+    end
+
+    class NFSCantReadExports < VagrantError
+      error_key(:nfs_cant_read_exports)
+    end
+
     class NFSNoGuestIP < VagrantError
       error_key(:nfs_no_guest_ip)
     end
@@ -331,6 +384,14 @@ module Vagrant
       error_key(:nfs_no_hostonly_network)
     end
 
+    class NFSNoValidIds < VagrantError
+      error_key(:nfs_no_valid_ids)
+    end
+
+    class NoDefaultSyncedFolderImpl < VagrantError
+      error_key(:no_default_synced_folder_impl)
+    end
+
     class NoEnvironmentError < VagrantError
       error_key(:no_env)
     end
@@ -359,6 +420,10 @@ module Vagrant
       error_key(:provider_not_found)
     end
 
+    class ProvisionerFlagInvalid < VagrantError
+      error_key(:provisioner_flag_invalid)
+    end
+
     class PluginGemError < VagrantError
       error_key(:plugin_gem_error)
     end
@@ -391,6 +456,14 @@ module Vagrant
       error_key(:plugin_not_found)
     end
 
+    class PluginNotInstalled < VagrantError
+      error_key(:plugin_not_installed)
+    end
+
+    class PluginStateFileParseError < VagrantError
+      error_key(:plugin_state_file_not_parsable)
+    end
+
     class SCPPermissionDenied < VagrantError
       error_key(:scp_permission_denied)
     end
@@ -447,6 +520,10 @@ module Vagrant
       error_key(:ssh_key_type_not_supported)
     end
 
+    class SSHNoRoute < VagrantError
+      error_key(:ssh_no_route)
+    end
+
     class SSHNotReady < VagrantError
       error_key(:ssh_not_ready)
     end
@@ -463,6 +540,10 @@ module Vagrant
       error_key(:ssh_unavailable_windows)
     end
 
+    class SyncedFolderUnusable < VagrantError
+      error_key(:synced_folder_unusable)
+    end
+
     class UIExpectsTTY < VagrantError
       error_key(:ui_expects_tty)
     end
@@ -487,6 +568,14 @@ module Vagrant
       error_key(:vagrantfile_syntax_error)
     end
 
+    class VagrantfileWriteError < VagrantError
+      error_key(:vagrantfile_write_error)
+    end
+
+    class VagrantVersionBad < VagrantError
+      error_key(:vagrant_version_bad)
+    end
+
     class VBoxManageError < VagrantError
       error_key(:vboxmanage_error)
     end
@@ -495,6 +584,14 @@ module Vagrant
       error_key(:vboxmanage_not_found_error)
     end
 
+    class VirtualBoxBrokenVersion040214 < VagrantError
+      error_key(:virtualbox_broken_version_040214)
+    end
+
+    class VirtualBoxGuestPropertyNotFound < VagrantError
+      error_key(:virtualbox_guest_property_not_found)
+    end
+
     class VirtualBoxInvalidVersion < VagrantError
       error_key(:virtualbox_invalid_version)
     end
@@ -519,6 +616,14 @@ module Vagrant
       error_key(:no_base_mac, "vagrant.actions.vm.match_mac")
     end
 
+    class VMBootBadState < VagrantError
+      error_key(:boot_bad_state)
+    end
+
+    class VMBootTimeout < VagrantError
+      error_key(:boot_timeout)
+    end
+
     class VMCustomizationFailed < VagrantError
       error_key(:failure, "vagrant.actions.vm.customize")
     end
