@@ -31,6 +31,14 @@ module Vagrant
         define_method(method) { |*args| }
       end
 
+      # For machine-readable output.
+      #
+      # @param [String] type The type of the data
+      # @param [Array] data The data associated with the type
+      def machine(type, *data)
+        @logger.info("Machine: #{type} #{data.inspect}")
+      end
+
       # Returns a new UI class that is scoped to the given resource name.
       # Subclasses can then use this scope name to do whatever they please.
       #
@@ -51,6 +59,46 @@ module Vagrant
       end
     end
 
+    class MachineReadable < Interface
+      include Util::SafePuts
+
+      def initialize
+        super
+
+        @lock = Mutex.new
+      end
+
+      def ask(*args)
+        super
+
+        # Machine-readable can't ask for input
+        raise Errors::UIExpectsTTY
+      end
+
+      def machine(type, *data)
+        opts = {}
+        opts = data.pop if data.last.kind_of?(Hash)
+
+        target = opts[:scope] || ""
+
+        # Prepare the data by replacing characters that aren't outputted
+        data.each_index do |i|
+          data[i] = data[i].to_s
+          data[i].gsub!(",", "%!(VAGRANT_COMMA)")
+          data[i].gsub!("\n", "\\n")
+          data[i].gsub!("\r", "\\r")
+        end
+
+        @lock.synchronize do
+          safe_puts("#{Time.now.utc.to_i},#{target},#{type},#{data.join(",")}")
+        end
+      end
+
+      def scope(scope_name)
+        BasicScope.new(self, scope_name)
+      end
+    end
+
     # This is a UI implementation that outputs the text as is. It
     # doesn't add any color.
     class Basic < Interface
@@ -113,7 +161,6 @@ module Vagrant
 
       def clear_line
         reset = "\r"
-        reset += "\e[0K" if Util::Platform.windows? && !Util::Platform.cygwin?
 
         info(reset, :new_line => false)
       end
@@ -133,11 +180,15 @@ module Vagrant
         channel = type == :error || opts[:channel] == :error ? $stderr : $stdout
 
         # Output! We wrap this in a lock so that it safely outputs only
-        # one line at a time.
-        @lock.synchronize do
-          safe_puts(format_message(type, message, opts),
-                    :io => channel, :printer => printer)
-        end
+        # one line at a time. We wrap this in a thread because as of Ruby 2.0
+        # we can't acquire locks in a trap context (ctrl-c), so we have to
+        # do this.
+        Thread.new do
+          @lock.synchronize do
+            safe_puts(format_message(type, message, opts),
+                      :io => channel, :printer => printer)
+          end
+        end.join
       end
 
       def scope(scope_name)
@@ -173,6 +224,14 @@ module Vagrant
         # By default do nothing, these aren't logged
         define_method(method) { |*args| @ui.send(method, *args) }
       end
+
+      def machine(type, *data)
+        opts = {}
+        opts = data.pop if data.last.is_a?(Hash)
+        opts[:scope] = @scope
+        data << opts
+        @ui.machine(type, *data)
+      end
     end
 
     # This is a UI implementation that outputs color for various types
