@@ -5,6 +5,7 @@ require 'log4r'
 
 require 'vagrant/util/platform'
 require 'vagrant/util/safe_chdir'
+require 'vagrant/util/which'
 
 module Vagrant
   module Util
@@ -25,7 +26,13 @@ module Vagrant
 
       def initialize(*command)
         @options = command.last.is_a?(Hash) ? command.pop : {}
-        @command = command
+        @command = command.dup
+        @command[0] = Which.which(@command[0]) if !File.file?(@command[0])
+        if !@command[0]
+          raise Errors::CommandUnavailableWindows, file: command[0] if Platform.windows?
+          raise Errors::CommandUnavailable, file: command[0]
+        end
+
         @logger  = Log4r::Logger.new("vagrant::util::subprocess")
       end
 
@@ -66,6 +73,25 @@ module Vagrant
         process.io.stderr = stderr_writer
         process.duplex = true
 
+        # If we're in an installer on Mac and we're executing a command
+        # in the installer context, then force DYLD_LIBRARY_PATH to look
+        # at our libs first.
+        if Vagrant.in_installer? && Platform.darwin?
+          installer_dir = ENV["VAGRANT_INSTALLER_EMBEDDED_DIR"].to_s.downcase
+          if @command[0].downcase.include?(installer_dir)
+            @logger.info("Command in the installer. Specifying DYLD_LIBRARY_PATH...")
+            process.environment["DYLD_LIBRARY_PATH"] =
+              "#{installer_dir}/lib:#{ENV["DYLD_LIBRARY_PATH"]}"
+          else
+            @logger.debug("Command not in installer, not touching env vars.")
+          end
+
+          if File.setuid?(@command[0]) || File.setgid?(@command[0])
+            @logger.info("Command is setuid/setgid, clearing DYLD_LIBRARY_PATH")
+            process.environment["DYLD_LIBRARY_PATH"] = ""
+          end
+        end
+
         # Set the environment on the process if we must
         if @options[:env]
           @options[:env].each do |k, v|
