@@ -11,6 +11,18 @@ module VagrantPlugins
             o.banner = "Usage: vagrant box add <name> <url> [--provider provider] [-h]"
             o.separator ""
 
+            o.on("--checksum VALUE", String, "Checksum") do |c|
+              options[:checksum] = c
+            end
+
+            o.on("--checksum-type VALUE", String, "Checksum type") do |c|
+              options[:checksum_type] = c.to_sym
+            end
+
+            o.on("-c", "--clean", "Remove old temporary download if it exists.") do |c|
+              options[:clean] = c
+            end
+
             o.on("-f", "--force", "Overwrite an existing box if it exists.") do |f|
               options[:force] = f
             end
@@ -19,6 +31,15 @@ module VagrantPlugins
               options[:insecure] = i
             end
 
+            o.on("--cacert certfile", String, "CA certificate") do |c|
+              options[:ca_cert] = c
+            end
+
+            o.on("--cert certfile", String,
+                 "The client SSL cert") do |c|
+              options[:client_cert] = c
+            end
+
             o.on("--provider provider", String,
                  "The provider that backs the box.") do |p|
               options[:provider] = p
@@ -38,7 +59,12 @@ module VagrantPlugins
             :box_name     => argv[0],
             :box_provider => provider,
             :box_url      => argv[1],
+            :box_checksum_type => options[:checksum_type],
+            :box_checksum => options[:checksum],
+            :box_clean    => options[:clean],
             :box_force    => options[:force],
+            :box_download_ca_cert => options[:ca_cert],
+            :box_download_client_cert => options[:client_cert],
             :box_download_insecure => options[:insecure],
           })
 
