@@ -7,8 +7,13 @@ module VagrantPlugins
         def execute
           options = {}
 
-          opts = OptionParser.new do |opts|
-            opts.banner = "Usage: vagrant box list"
+          opts = OptionParser.new do |o|
+            o.banner = "Usage: vagrant box list"
+            o.separator ""
+
+            o.on("-i", "--box-info", "Displays additional information about the boxes.") do |i|
+              options[:info] = i
+            end
           end
 
           # Parse the options
@@ -20,6 +25,15 @@ module VagrantPlugins
             return @env.ui.warn(I18n.t("vagrant.commands.box.no_installed_boxes"), :prefix => false)
           end
 
+          list_boxes(boxes, options[:info])
+
+          # Success, exit status 0
+          0
+        end
+
+        private
+
+        def list_boxes(boxes, extra_info)
           # Find the longest box name
           longest_box = boxes.max_by { |x| x[0].length }
           longest_box_length = longest_box[0].length
@@ -30,10 +44,22 @@ module VagrantPlugins
           # and which don't, since we plan on doing that transparently.
           boxes.each do |name, provider, _v1|
             @env.ui.info("#{name.ljust(longest_box_length)} (#{provider})", :prefix => false)
-          end
 
-          # Success, exit status 0
-          0
+            @env.ui.machine("box-name", name)
+            @env.ui.machine("box-provider", provider)
+
+            info_file = @env.boxes.find(name, provider).directory.join("info.json")
+            if info_file.file?
+              info = JSON.parse(info_file.read)
+              info.each do |k, v|
+                @env.ui.machine("box-info", k, v)
+
+                if extra_info
+                  @env.ui.info("  - #{k}: #{v}", prefix: false)
+                end
+              end
+            end
+          end
         end
       end
     end
