@@ -11,8 +11,13 @@ module VagrantPlugins
       # to this.
       include VagrantPlugins::CommandUp::StartMixins
 
+      def self.synopsis
+        "restarts vagrant machine, loads new Vagrantfile configuration"
+      end
+
       def execute
         options = {}
+        options[:provision_ignore_sentinel] = false
 
         opts = OptionParser.new do |o|
           o.banner = "Usage: vagrant reload [vm-name]"
@@ -24,6 +29,9 @@ module VagrantPlugins
         argv = parse_options(opts)
         return if !argv
 
+        # Validate the provisioners
+        validate_provisioner_flags!(options)
+
         @logger.debug("'reload' each target VM...")
         with_target_vms(argv) do |machine|
           machine.action(:reload, options)
