@@ -9,9 +9,15 @@ module VagrantPlugins
     class Command < Vagrant.plugin("2", :command)
       include StartMixins
 
+      def self.synopsis
+        "starts and provisions the vagrant environment"
+      end
+
       def execute
         options = {}
+        options[:destroy_on_error] = true
         options[:parallel] = true
+        options[:provision_ignore_sentinel] = false
 
         opts = OptionParser.new do |o|
           o.banner = "Usage: vagrant up [vm-name] [options] [-h]"
@@ -19,6 +25,11 @@ module VagrantPlugins
 
           build_start_options(o, options)
 
+          o.on("--[no-]destroy-on-error",
+               "Destroy machine if any fatal error happens (default to true).") do |destroy|
+            options[:destroy_on_error] = destroy
+          end
+
           o.on("--[no-]parallel",
                "Enable or disable parallelism if provider supports it.") do |parallel|
             options[:parallel] = parallel
@@ -34,6 +45,9 @@ module VagrantPlugins
         argv = parse_options(opts)
         return if !argv
 
+        # Validate the provisioners
+        validate_provisioner_flags!(options)
+
         # Go over each VM and bring it up
         @logger.debug("'Up' each target VM...")
 
