@@ -5,6 +5,7 @@ require 'timeout'
 
 require 'log4r'
 require 'net/ssh'
+require 'net/ssh/proxy/command'
 require 'net/scp'
 
 require 'vagrant/util/ansi_escape_code_remover'
@@ -53,12 +54,23 @@ module VagrantPlugins
           :error_class => Vagrant::Errors::VagrantError,
           :error_key   => :ssh_bad_exit_status,
           :command     => command,
+          :shell       => nil,
           :sudo        => false
         }.merge(opts || {})
 
         # Connect via SSH and execute the command in the shell.
+        stdout = ""
+        stderr = ""
         exit_status = connect do |connection|
-          shell_execute(connection, command, opts[:sudo], &block)
+          shell_execute(connection, command, opts[:sudo], opts[:shell]) do |type, data|
+            if type == :stdout
+              stdout += data
+            elsif type == :stderr
+              stderr += data
+            end
+
+            block.call(type, data) if block
+          end
         end
 
         # Check for any errors
@@ -66,7 +78,11 @@ module VagrantPlugins
           # The error classes expect the translation key to be _key,
           # but that makes for an ugly configuration parameter, so we
           # set it here from `error_key`
-          error_opts = opts.merge(:_key => opts[:error_key])
+          error_opts = opts.merge(
+            :_key => opts[:error_key],
+            :stdout => stdout,
+            :stderr => stderr
+          )
           raise opts[:error_class], error_opts
         end
 
@@ -151,7 +167,7 @@ module VagrantPlugins
           :auth_methods          => ["none", "publickey", "hostbased", "password"],
           :config                => false,
           :forward_agent         => ssh_info[:forward_agent],
-          :keys                  => [ssh_info[:private_key_path]],
+          :keys                  => ssh_info[:private_key_path],
           :keys_only             => true,
           :paranoid              => false,
           :port                  => ssh_info[:port],
@@ -159,7 +175,9 @@ module VagrantPlugins
         }
 
         # Check that the private key permissions are valid
-        Vagrant::Util::SSH.check_key_permissions(Pathname.new(ssh_info[:private_key_path]))
+        ssh_info[:private_key_path].each do |path|
+          Vagrant::Util::SSH.check_key_permissions(Pathname.new(path))
+        end
 
         # Connect to SSH, giving it a few tries
         connection = nil
@@ -172,15 +190,16 @@ module VagrantPlugins
             Errno::EADDRINUSE,
             Errno::ECONNREFUSED,
             Errno::ECONNRESET,
+            Errno::ENETUNREACH,
             Errno::EHOSTUNREACH,
             Net::SSH::Disconnect,
             Timeout::Error
           ]
 
-          retries = @machine.config.ssh.max_tries
-          timeout = @machine.config.ssh.timeout
+          retries = 5
+          timeout = 60
 
-          @logger.info("Attempting SSH. Retries: #{retries}. Timeout: #{timeout}")
+          @logger.info("Attempting SSH connnection...")
           connection = retryable(:tries => retries, :on => exceptions) do
             Timeout.timeout(timeout) do
               begin
@@ -191,9 +210,14 @@ module VagrantPlugins
                 # Setup logging for connections
                 connect_opts = opts.merge({
                   :logger  => ssh_logger,
+                  :timeout => 15,
                   :verbose => :debug
                 })
 
+                if ssh_info[:proxy_command]
+                  connect_opts[:proxy] = Net::SSH::Proxy::Command.new(ssh_info[:proxy_command])
+                end
+
                 @logger.info("Attempting to connect to SSH...")
                 @logger.info("  - Host: #{ssh_info[:host]}")
                 @logger.info("  - Port: #{ssh_info[:port]}")
@@ -235,6 +259,9 @@ module VagrantPlugins
         rescue Errno::EHOSTDOWN
           # This is raised if we get an ICMP DestinationUnknown error.
           raise Vagrant::Errors::SSHHostDown
+        rescue Errno::EHOSTUNREACH
+          # This is raised if we can't work out how to route traffic.
+          raise Vagrant::Errors::SSHNoRoute
         rescue NotImplementedError
           # This is raised if a private key type that Net-SSH doesn't support
           # is used. Show a nicer error.
@@ -249,18 +276,30 @@ module VagrantPlugins
       end
 
       # Executes the command on an SSH connection within a login shell.
-      def shell_execute(connection, command, sudo=false)
+      def shell_execute(connection, command, sudo=false, shell=nil)
         @logger.info("Execute: #{command} (sudo=#{sudo.inspect})")
         exit_status = nil
 
-        # Determine the shell to execute. If we are using `sudo` then we
+        # Determine the shell to execute. Prefer the explicitly passed in shell
+        # over the default configured shell. If we are using `sudo` then we
         # need to wrap the shell in a `sudo` call.
-        shell = @machine.config.ssh.shell
-        shell = "sudo -H #{shell}" if sudo
+        shell_cmd = @machine.config.ssh.shell
+        shell_cmd = shell if shell
+        shell_cmd = "sudo -E -H #{shell_cmd}" if sudo
 
         # Open the channel so we can execute or command
         channel = connection.open_channel do |ch|
-          ch.exec(shell) do |ch2, _|
+          if @machine.config.ssh.pty
+            ch.request_pty do |ch2, success|
+              if success
+                @logger.debug("pty obtained for connection")
+              else
+                @logger.warn("failed to obtain pty, will try to continue anyways")
+              end
+            end
+          end
+
+          ch.exec(shell_cmd) do |ch2, _|
             # Setup the channel callbacks so we can get data and exit status
             ch2.on_data do |ch3, data|
               # Filter out the clear screen command
@@ -279,11 +318,40 @@ module VagrantPlugins
             ch2.on_request("exit-status") do |ch3, data|
               exit_status = data.read_long
               @logger.debug("Exit status: #{exit_status}")
+
+              # Close the channel, since after the exit status we're
+              # probably done. This fixes up issues with hanging.
+              channel.close
             end
 
             # Set the terminal
             ch2.send_data "export TERM=vt100\n"
 
+            # Set SSH_AUTH_SOCK if we are in sudo and forwarding agent.
+            # This is to work around often misconfigured boxes where
+            # the SSH_AUTH_SOCK env var is not preserved.
+            if @machine.ssh_info[:forward_agent] && sudo
+              auth_socket = ""
+              execute("echo; printf $SSH_AUTH_SOCK") do |type, data|
+                if type == :stdout
+                  auth_socket += data
+                end
+              end
+
+              if auth_socket != ""
+                # Make sure we only read the last line which should be
+                # the $SSH_AUTH_SOCK env var we printed.
+                auth_socket = auth_socket.split("\n").last.chomp
+              end
+
+              if auth_socket == ""
+                @logger.warn("No SSH_AUTH_SOCK found despite forward_agent being set.")
+              else
+                @logger.info("Setting SSH_AUTH_SOCK remotely: #{auth_socket}")
+                ch2.send_data "export SSH_AUTH_SOCK=#{auth_socket}\n"
+              end
+            end
+
             # Output the command
             ch2.send_data "#{command}\n"
 
@@ -312,7 +380,12 @@ module VagrantPlugins
           end
 
           # Wait for the channel to complete
-          channel.wait
+          begin
+            channel.wait
+          rescue IOError
+            @logger.info("SSH connection unexpected closed. Assuming reboot or something.")
+            exit_status = 0
+          end
         ensure
           # Kill the keep-alive thread
           keep_alive.kill if keep_alive
