@@ -10,7 +10,7 @@ module VagrantPlugins
 
         def self.configure_networks(machine, networks)
           # Remove any previous network additions to the configuration file.
-          machine.communicate.sudo("sed -i '' -e '/^#VAGRANT-BEGIN/,/^#VAGRANT-END/ d' /etc/rc.conf")
+          machine.communicate.sudo("sed -i '' -e '/^#VAGRANT-BEGIN/,/^#VAGRANT-END/ d' /etc/rc.conf", {:shell => "sh"})
 
           networks.each do |network|
             entry = TemplateRenderer.render("guests/freebsd/network_#{network[:type]}",
@@ -23,13 +23,13 @@ module VagrantPlugins
             temp.close
 
             machine.communicate.upload(temp.path, "/tmp/vagrant-network-entry")
-            machine.communicate.sudo("su -m root -c 'cat /tmp/vagrant-network-entry >> /etc/rc.conf'")
-            machine.communicate.sudo("rm /tmp/vagrant-network-entry")
+            machine.communicate.sudo("su -m root -c 'cat /tmp/vagrant-network-entry >> /etc/rc.conf'", {:shell => "sh"})
+            machine.communicate.sudo("rm /tmp/vagrant-network-entry", {:shell => "sh"})
 
             if network[:type].to_sym == :static
-              machine.communicate.sudo("ifconfig em#{network[:interface]} inet #{network[:ip]} netmask #{network[:netmask]}")
+              machine.communicate.sudo("ifconfig em#{network[:interface]} inet #{network[:ip]} netmask #{network[:netmask]}", {:shell => "sh"})
             elsif network[:type].to_sym == :dhcp
-              machine.communicate.sudo("dhclient em#{network[:interface]}")
+              machine.communicate.sudo("dhclient em#{network[:interface]}", {:shell => "sh"})
             end
           end
         end
