@@ -16,12 +16,27 @@ module VagrantPlugins
             machine.communicate.sudo("mkdir -p #{expanded_guest_path}")
 
             # Mount
-            mount_command = "mount -o vers=#{opts[:nfs_version]} #{ip}:'#{opts[:hostpath]}' #{expanded_guest_path}"
+            hostpath = opts[:hostpath].dup
+            hostpath.gsub!("'", "'\\\\''")
 
-            retryable(:on => Vagrant::Errors::LinuxNFSMountFailed, :tries => 5, :sleep => 2) do
+            # Figure out any options
+            mount_opts = ["vers=#{opts[:nfs_version]}"]
+            mount_opts << "udp" if opts[:nfs_udp]
+            if opts[:mount_options]
+              mount_opts = opts[:mount_options].dup
+            end
+
+            mount_command = "mount -o '#{mount_opts.join(",")}' #{ip}:'#{hostpath}' #{expanded_guest_path}"
+            retryable(:on => Vagrant::Errors::LinuxNFSMountFailed, :tries => 8, :sleep => 3) do
               machine.communicate.sudo(mount_command,
                                        :error_class => Vagrant::Errors::LinuxNFSMountFailed)
             end
+
+            # Emit an upstart event if we can
+            if machine.communicate.test("test -x /sbin/initctl")
+              machine.communicate.sudo(
+                "/sbin/initctl emit --no-wait vagrant-mounted MOUNTPOINT=#{expanded_guest_path}")
+            end
           end
         end
       end
