@@ -18,6 +18,10 @@ module VagrantPlugins
         @port             = nil if @port == UNSET_VALUE
         @private_key_path = nil if @private_key_path == UNSET_VALUE
         @username         = nil if @username == UNSET_VALUE
+
+        if @private_key_path && !@private_key_path.is_a?(Array)
+          @private_key_path = [@private_key_path]
+        end
       end
 
       # NOTE: This is _not_ a valid config validation method, since it
@@ -28,9 +32,15 @@ module VagrantPlugins
       def validate(machine)
         errors = _detected_errors
 
-        if @private_key_path && \
-          !File.file?(File.expand_path(@private_key_path, machine.env.root_path))
-          errors << I18n.t("vagrant.config.ssh.private_key_missing", :path => @private_key_path)
+        if @private_key_path
+          @private_key_path.each do |raw_path|
+            path = File.expand_path(raw_path, machine.env.root_path)
+            if !File.file?(path)
+              errors << I18n.t(
+                "vagrant.config.ssh.private_key_missing",
+                path: raw_path)
+            end
+          end
         end
 
         errors
