@@ -4,6 +4,7 @@ require "set"
 
 require "vagrant"
 require "vagrant/config/v2/util"
+require "vagrant/util/platform"
 
 require File.expand_path("../vm_provisioner", __FILE__)
 require File.expand_path("../vm_subvm", __FILE__)
@@ -14,18 +15,30 @@ module VagrantPlugins
       DEFAULT_VM_NAME = :default
 
       attr_accessor :base_mac
+      attr_accessor :boot_timeout
       attr_accessor :box
       attr_accessor :box_url
-      attr_accessor :graceful_halt_retry_count
-      attr_accessor :graceful_halt_retry_interval
+      attr_accessor :box_download_ca_cert
+      attr_accessor :box_download_checksum
+      attr_accessor :box_download_checksum_type
+      attr_accessor :box_download_client_cert
+      attr_accessor :box_download_insecure
+      attr_accessor :graceful_halt_timeout
       attr_accessor :guest
       attr_accessor :hostname
       attr_accessor :usable_port_range
       attr_reader :provisioners
 
       def initialize
-        @graceful_halt_retry_count    = UNSET_VALUE
-        @graceful_halt_retry_interval = UNSET_VALUE
+        @boot_timeout                 = UNSET_VALUE
+        @box_download_ca_cert         = UNSET_VALUE
+        @box_download_checksum        = UNSET_VALUE
+        @box_download_checksum_type   = UNSET_VALUE
+        @box_download_client_cert     = UNSET_VALUE
+        @box_download_insecure        = UNSET_VALUE
+        @box_url                      = UNSET_VALUE
+        @graceful_halt_timeout        = UNSET_VALUE
+        @guest                        = UNSET_VALUE
         @hostname                     = UNSET_VALUE
         @provisioners                 = []
 
@@ -40,6 +53,12 @@ module VagrantPlugins
         @__synced_folders              = {}
       end
 
+      # This was from V1, but we just kept it here as an alias for hostname
+      # because too many people mess this up.
+      def host_name=(value)
+        @hostname = value
+      end
+
       # Custom merge method since some keys here are merged differently.
       def merge(other)
         super.tap do |result|
@@ -90,7 +109,11 @@ module VagrantPlugins
 
           # Merge synced folders.
           other_folders = other.instance_variable_get(:@__synced_folders)
-          new_folders = @__synced_folders.dup
+          new_folders = {}
+          @__synced_folders.each do |key, value|
+            new_folders[key] = value.dup
+          end
+
           other_folders.each do |id, options|
             new_folders[id] ||= {}
             new_folders[id].merge!(options)
@@ -117,7 +140,14 @@ module VagrantPlugins
       #   folder.
       # @param [Hash] options Additional options.
       def synced_folder(hostpath, guestpath, options=nil)
+        if Vagrant::Util::Platform.windows?
+          # On Windows, Ruby just uses normal '/' for path seps, so
+          # just replace normal Windows style seps with Unix ones.
+          hostpath = hostpath.to_s.gsub("\\", "/")
+        end
+
         options ||= {}
+        options = options.dup
         options[:guestpath] = guestpath.to_s.gsub(/\/$/, '')
         options[:hostpath]  = hostpath
 
@@ -142,6 +172,8 @@ module VagrantPlugins
       # @param [Hash] options Options for the network.
       def network(type, options=nil)
         options ||= {}
+        options = options.dup
+        options[:protocol] ||= "tcp"
 
         if !options[:id]
           default_id = nil
@@ -149,7 +181,7 @@ module VagrantPlugins
           if type == :forwarded_port
             # For forwarded ports, set the default ID to the
             # host port so that host ports overwrite each other.
-            default_id = options[:host]
+            default_id = "#{options[:protocol]}#{options[:host]}"
           end
 
           options[:id] = default_id || SecureRandom.uuid
@@ -204,6 +236,7 @@ module VagrantPlugins
       def define(name, options=nil, &block)
         name = name.to_sym
         options ||= {}
+        options = options.dup
         options[:config_version] ||= "2"
 
         # Add the name to the array of VM keys. This array is used to
@@ -225,12 +258,45 @@ module VagrantPlugins
 
       def finalize!
         # Defaults
+        @boot_timeout = 300 if @boot_timeout == UNSET_VALUE
+        @box_download_ca_cert = nil if @box_download_ca_cert == UNSET_VALUE
+        @box_download_checksum = nil if @box_download_checksum == UNSET_VALUE
+        @box_download_checksum_type = nil if @box_download_checksum_type == UNSET_VALUE
+        @box_download_client_cert = nil if @box_download_client_cert == UNSET_VALUE
+        @box_download_insecure = false if @box_download_insecure == UNSET_VALUE
+        @box_url = nil if @box_url == UNSET_VALUE
+        @graceful_halt_timeout = 300 if @graceful_halt_timeout == UNSET_VALUE
+        @guest = nil if @guest == UNSET_VALUE
         @hostname = nil if @hostname == UNSET_VALUE
+        @hostname = @hostname.to_s if @hostname
+
+        # Make sure that the download checksum is a string and that
+        # the type is a symbol
+        @box_download_checksum = "" if !@box_download_checksum
+        if @box_download_checksum_type
+          @box_download_checksum_type = @box_download_checksum_type.to_sym
+        end
+
+        # Make sure the box URL is an array if it is set
+        if @box_url && !@box_url.is_a?(Array)
+          @box_url = [@box_url]
+        end
+
+        # Set the guest properly
+        @guest = @guest.to_sym if @guest
 
         # If we haven't defined a single VM, then we need to define a
         # default VM which just inherits the rest of the configuration.
         define(DEFAULT_VM_NAME) if defined_vm_keys.empty?
 
+        # Clean up some network configurations
+        @__networks.each do |type, opts|
+          if type == :forwarded_port
+            opts[:guest] = opts[:guest].to_i if opts[:guest]
+            opts[:host] = opts[:host].to_i if opts[:host]
+          end
+        end
+
         # Compile all the provider configurations
         @__providers.each do |name, blocks|
           # If we don't have any configuration blocks, then ignore it
@@ -253,6 +319,20 @@ module VagrantPlugins
           @__compiled_provider_configs[name]   = config
         end
 
+        @__synced_folders.each do |id, options|
+          if options[:nfs]
+            options[:type] = :nfs
+          end
+
+          # Make sure the type is a symbol
+          options[:type] = options[:type].to_sym if options[:type]
+
+          # Ignore NFS on Windows
+          if options[:type] == :nfs && Vagrant::Util::Platform.windows?
+            options.delete(:type)
+          end
+        end
+
         # Flag that we finalized
         @__finalized = true
       end
@@ -306,7 +386,27 @@ module VagrantPlugins
         errors << I18n.t("vagrant.config.vm.box_not_found", :name => box) if \
           box && !box_url && !machine.box
         errors << I18n.t("vagrant.config.vm.hostname_invalid_characters") if \
-          @hostname && @hostname !~ /^[-.a-z0-9]+$/i
+          @hostname && @hostname !~ /^[a-z0-9][-.a-z0-9]+$/i
+
+        if box_download_ca_cert
+          path = Pathname.new(box_download_ca_cert).
+            expand_path(machine.env.root_path)
+          if !path.file?
+            errors << I18n.t(
+              "vagrant.config.vm.box_download_ca_cert_not_found",
+              path: box_download_ca_cert)
+          end
+        end
+
+        if box_download_checksum_type
+          if box_download_checksum == ""
+            errors << I18n.t("vagrant.config.vm.box_download_checksum_blank")
+          end
+        else
+          if box_download_checksum != ""
+            errors << I18n.t("vagrant.config.vm.box_download_checksum_notblank")
+          end
+        end
 
         has_nfs = false
         used_guest_paths = Set.new
@@ -317,7 +417,7 @@ module VagrantPlugins
           guestpath = Pathname.new(options[:guestpath])
           hostpath  = Pathname.new(options[:hostpath]).expand_path(machine.env.root_path)
 
-          if guestpath.relative?
+          if guestpath.relative? && guestpath.to_s !~ /^\w+:/
             errors << I18n.t("vagrant.config.vm.shared_folder_guestpath_relative",
                              :path => options[:guestpath])
           else
@@ -334,7 +434,7 @@ module VagrantPlugins
                              :path => options[:hostpath])
           end
 
-          if options[:nfs]
+          if options[:type] == :nfs
             has_nfs = true
 
             if options[:owner] || options[:group]
@@ -343,6 +443,15 @@ module VagrantPlugins
                                :path => options[:hostpath])
             end
           end
+
+          if options[:mount_options] && !options[:mount_options].is_a?(Array)
+            errors << I18n.t("vagrant.config.vm.shared_folder_mount_options_array")
+          end
+
+          # One day remove this probably.
+          if options[:extra]
+            errors << "The 'extra' flag on synced folders is now 'mount_options'"
+          end
         end
 
         if has_nfs
@@ -356,7 +465,7 @@ module VagrantPlugins
 
         # Validate networks
         has_fp_port_error = false
-        fp_host_ports     = Set.new
+        fp_used = Set.new
         valid_network_types = [:forwarded_port, :private_network, :public_network]
 
         networks.each do |type, options|
@@ -372,12 +481,26 @@ module VagrantPlugins
             end
 
             if options[:host]
-              if fp_host_ports.include?(options[:host])
+              key = "#{options[:protocol]}#{options[:host]}"
+              if fp_used.include?(key)
                 errors << I18n.t("vagrant.config.vm.network_fp_host_not_unique",
-                                :host => options[:host].to_s)
+                                :host => options[:host].to_s,
+                                :protocol => options[:protocol].to_s)
               end
 
-              fp_host_ports.add(options[:host])
+              fp_used.add(key)
+            end
+          end
+
+          if type == :private_network
+            if options[:type] != :dhcp
+              if !options[:ip]
+                errors << I18n.t("vagrant.config.vm.network_ip_required")
+              end
+            end
+
+            if options[:ip] && options[:ip].end_with?(".1")
+              errors << I18n.t("vagrant.config.vm.network_ip_ends_in_one")
             end
           end
         end
