@@ -14,7 +14,7 @@ module VagrantPlugins
               logger.info("Installing CFEngine Community Yum Repository GPG KEY from #{config.repo_gpg_key_url}")
               comm.sudo("GPGFILE=$(mktemp) && wget -O $GPGFILE #{config.repo_gpg_key_url} && rpm --import $GPGFILE; rm -f $GPGFILE")
 
-              comm.sudo("yum -y install cfengine-community")
+              comm.sudo("yum -y install #{config.package_name}")
             end
           end
         end
