@@ -1,4 +1,5 @@
 require 'pathname'
+require 'vagrant/util/subprocess'
 
 require File.expand_path("../base", __FILE__)
 
@@ -25,6 +26,11 @@ module VagrantPlugins
           run_chef_client
         end
 
+        def cleanup
+          delete_from_chef_server('client') if @config.delete_client
+          delete_from_chef_server('node') if @config.delete_node
+        end
+
         def create_client_key_folder
           @machine.env.ui.info I18n.t("vagrant.provisioners.chef.client_key_folder")
           path = Pathname.new(@config.client_key_path)
@@ -40,7 +46,7 @@ module VagrantPlugins
         def upload_encrypted_data_bag_secret
           @machine.env.ui.info I18n.t("vagrant.provisioners.chef.upload_encrypted_data_bag_secret_key")
           @machine.communicate.upload(encrypted_data_bag_secret_key_path,
-                                  @config.encrypted_data_bag_secret)
+            guest_encrypted_data_bag_secret_key_path)
         end
 
         def setup_server_config
@@ -50,10 +56,8 @@ module VagrantPlugins
             :validation_client_name => @config.validation_client_name,
             :validation_key => guest_validation_key_path,
             :client_key => @config.client_key_path,
-            :file_cache_path => @config.file_cache_path,
-            :file_backup_path => @config.file_backup_path,
             :environment => @config.environment,
-            :encrypted_data_bag_secret => @config.encrypted_data_bag_secret
+            :encrypted_data_bag_secret => guest_encrypted_data_bag_secret_key_path,
           })
         end
 
@@ -64,7 +68,9 @@ module VagrantPlugins
 
           command_env = @config.binary_env ? "#{@config.binary_env} " : ""
           command_args = @config.arguments ? " #{@config.arguments}" : ""
-          command = "#{command_env}#{chef_binary_path("chef-client")} -c #{@config.provisioning_path}/client.rb -j #{@config.provisioning_path}/dna.json #{command_args}"
+          command = "#{command_env}#{chef_binary_path("chef-client")} " +
+            "-c #{@config.provisioning_path}/client.rb " +
+            "-j #{@config.provisioning_path}/dna.json #{command_args}"
 
           @config.attempts.times do |attempt|
             if attempt == 0
@@ -76,10 +82,8 @@ module VagrantPlugins
             exit_status = @machine.communicate.sudo(command, :error_check => false) do |type, data|
               # Output the data with the proper color based on the stream.
               color = type == :stdout ? :green : :red
-
-              # Note: Be sure to chomp the data to avoid the newlines that the
-              # Chef outputs.
-              @machine.env.ui.info(data.chomp, :color => color, :prefix => false)
+              @machine.env.ui.info(
+                data, :color => color, :new_line => false, :prefix => false)
             end
 
             # There is no need to run Chef again if it converges
@@ -98,9 +102,31 @@ module VagrantPlugins
           File.expand_path(@config.encrypted_data_bag_secret_key_path, @machine.env.root_path)
         end
 
+        def guest_encrypted_data_bag_secret_key_path
+          File.join(@config.provisioning_path,
+            "encrypted_data_bag_secret_key.pem")
+        end
+
         def guest_validation_key_path
           File.join(@config.provisioning_path, "validation.pem")
         end
+
+        def delete_from_chef_server(deletable)
+          node_name = @config.node_name || @machine.config.vm.hostname
+          @machine.env.ui.info(I18n.t(
+            "vagrant.provisioners.chef.deleting_from_server",
+            deletable: deletable, name: node_name))
+
+          command = ["knife", deletable, "delete", "--yes", node_name]
+          r = Vagrant::Util::Subprocess.execute(*command)
+          if r.exit_code != 0
+            @machine.env.ui.error(I18n.t(
+              "vagrant.chef_client_cleanup_failed",
+              deletable: deletable,
+              stdout: r.stdout,
+              stderr: r.stderr))
+          end
+        end
       end
     end
   end
