@@ -1,3 +1,5 @@
+require 'uri'
+
 module VagrantPlugins
   module Shell
     class Config < Vagrant.plugin("2", :config)
@@ -5,12 +7,18 @@ module VagrantPlugins
       attr_accessor :path
       attr_accessor :upload_path
       attr_accessor :args
+      attr_accessor :privileged
+      attr_accessor :binary
+      attr_accessor :keep_color
 
       def initialize
         @args        = UNSET_VALUE
         @inline      = UNSET_VALUE
         @path        = UNSET_VALUE
         @upload_path = UNSET_VALUE
+        @privileged  = UNSET_VALUE
+        @binary      = UNSET_VALUE
+        @keep_color  = UNSET_VALUE
       end
 
       def finalize!
@@ -18,6 +26,9 @@ module VagrantPlugins
         @inline      = nil if @inline == UNSET_VALUE
         @path        = nil if @path == UNSET_VALUE
         @upload_path = "/tmp/vagrant-shell" if @upload_path == UNSET_VALUE
+        @privileged  = true if @privileged == UNSET_VALUE
+        @binary      = false if @binary == UNSET_VALUE
+        @keep_color  = false if @keep_color == UNSET_VALUE
       end
 
       def validate(machine)
@@ -30,8 +41,8 @@ module VagrantPlugins
           errors << I18n.t("vagrant.provisioners.shell.no_path_or_inline")
         end
 
-        # Validate the existence of a script to upload
-        if path
+        # If it is not an URL, we validate the existence of a script to upload
+        if path && ! remote?
           expanded_path = Pathname.new(path).expand_path(machine.env.root_path)
           if !expanded_path.file?
             errors << I18n.t("vagrant.provisioners.shell.path_invalid",
@@ -44,13 +55,23 @@ module VagrantPlugins
           errors << I18n.t("vagrant.provisioners.shell.upload_path_not_set")
         end
 
-        # If there are args and its not a string, that is a problem
-        if args && !args.is_a?(String)
-          errors << I18n.t("vagrant.provisioners.shell.args_not_string")
+        if !args_valid?
+          errors << I18n.t("vagrant.provisioners.shell.args_bad_type")
         end
 
         { "shell provisioner" => errors }
       end
+
+      # Args are optional, but if they're provided we only support them as a
+      # string or as an array.
+      def args_valid?
+        return true if !args
+        args.is_a?(String) || args.is_a?(Array)
+      end
+
+      def remote?
+        path =~ URI.regexp(["ftp", "http", "https"])
+      end
     end
   end
 end
