@@ -1,12 +1,20 @@
 require "pathname"
 require "tempfile"
 
+require "vagrant/util/downloader"
+
 module VagrantPlugins
   module Shell
     class Provisioner < Vagrant.plugin("2", :provisioner)
       def provision
         args = ""
-        args = " #{config.args}" if config.args
+        if config.args.is_a?(String)
+          args = " #{config.args}"
+        elsif config.args.is_a?(Array)
+          args = config.args.map { |a| quote_and_escape(a) }
+          args = " #{args.join(" ")}"
+        end
+
         command = "chmod +x #{config.upload_path} && #{config.upload_path}#{args}"
 
         with_script_file do |path|
@@ -28,14 +36,18 @@ module VagrantPlugins
             end
 
             # Execute it with sudo
-            comm.sudo(command) do |type, data|
+            comm.execute(command, sudo: config.privileged) do |type, data|
               if [:stderr, :stdout].include?(type)
                 # Output the data with the proper color based on the stream.
                 color = type == :stdout ? :green : :red
 
-                # Note: Be sure to chomp the data to avoid the newlines that the
-                # Chef outputs.
-                @machine.env.ui.info(data.chomp, :color => color, :prefix => false)
+                options = {
+                  new_line: false,
+                  prefix: false,
+                }
+                options[:color] = color if !config.keep_color
+
+                @machine.env.ui.info(data, options)
               end
             end
           end
@@ -44,13 +56,26 @@ module VagrantPlugins
 
       protected
 
+      # Quote and escape strings for shell execution, thanks to Capistrano.
+      def quote_and_escape(text, quote = '"')
+        "#{quote}#{text.gsub(/#{quote}/) { |m| "#{m}\\#{m}#{m}" }}#{quote}"
+      end
+
       # This method yields the path to a script to upload and execute
       # on the remote server. This method will properly clean up the
       # script file if needed.
       def with_script_file
         script = nil
 
-        if config.path
+        if config.remote?
+          download_path = @machine.env.tmp_path.join("#{@machine.id}-remote-script")
+          download_path.delete if download_path.file?
+
+          Vagrant::Util::Downloader.new(config.path, download_path).download!
+          script = download_path.read
+
+          download_path.delete
+        elsif config.path
           # Just yield the path to that file...
           root_path = @machine.env.root_path
           script = Pathname.new(config.path).expand_path(root_path).read
@@ -59,8 +84,8 @@ module VagrantPlugins
           script = config.inline
         end
 
-        # Replace Windows line endings with Unix ones
-        script.gsub!(/\r\n?$/, "\n")
+        # Replace Windows line endings with Unix ones unless binary file
+        script.gsub!(/\r\n?$/, "\n") if !config.binary
 
         # Otherwise we have an inline script, we need to Tempfile it,
         # and handle it specially...
