@@ -10,8 +10,11 @@ $:.unshift File.expand_path("../../", __FILE__)
 
 # Load in helpers
 require "support/tempdir"
+require "unit/support/dummy_communicator"
 require "unit/support/dummy_provider"
 require "unit/support/shared/base_context"
+require "unit/support/shared/action_synced_folders_context"
+require "unit/support/shared/virtualbox_context"
 
 # Do not buffer output
 $stdout.sync = true
