@@ -6,8 +6,10 @@ describe Vagrant::CLI do
 
     let(:environment) do
       ui = double("UI::Silent")
+      ui.stub(:machine => "bar")
       ui.stub(:info => "bar")
       env = double("Vagrant::Environment")
+      env.stub(:active_machines => [])
       env.stub(:ui => ui)
       env.stub(:root_path => "foo")
       env.stub(:machine_names => [])
