@@ -308,6 +308,30 @@ describe Vagrant::Environment do
 
       instance.hook(:bar).should == :foo
     end
+
+    it "should allow passing in a custom action runner" do
+      instance.action_runner.should_not_receive(:run)
+      other_runner = double("runner")
+      other_runner.should_receive(:run).and_return(:foo)
+
+      instance.hook(:bar, runner: other_runner).should == :foo
+    end
+
+    it "should allow passing in custom data" do
+      instance.action_runner.should_receive(:run).with do |callable, env|
+        env[:foo].should == :bar
+      end
+
+      instance.hook(:foo, foo: :bar)
+    end
+
+    it "should allow passing a custom callable" do
+      instance.action_runner.should_receive(:run).with do |callable, env|
+        callable.should == :what
+      end
+
+      instance.hook(:foo, callable: :what)
+    end
   end
 
   describe "primary machine name" do
@@ -581,6 +605,31 @@ VF
       machine.config.ssh.port.should == 100
     end
 
+    it "should load the box configuration for a V2 box and custom Vagrantfile name" do
+      register_provider("foo")
+
+      environment = isolated_environment do |env|
+        env.file("some_other_name", <<-VF)
+Vagrant.configure("2") do |config|
+  config.vm.box = "base"
+end
+VF
+
+        env.box2("base", :foo, :vagrantfile => <<-VF)
+Vagrant.configure("2") do |config|
+  config.ssh.port = 100
+end
+VF
+      end
+
+      env = with_temp_env("VAGRANT_VAGRANTFILE" => "some_other_name") do
+        environment.create_vagrant_env
+      end
+
+      machine = env.machine(:default, :foo)
+      machine.config.ssh.port.should == 100
+    end
+
     it "should load the box configuration for other formats for a V2 box" do
       register_provider("foo", nil, box_format: "bar")
 
